==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceClassSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterServiceClassSpecBuilder extends ClusterServiceClassSpecFluentImpl<ClusterServiceClassSpecBuilder> implements VisitableBuilder<ClusterServiceClassSpec,ClusterServiceClassSpecBuilder>{
  public ClusterServiceClassSpecBuilder() {
    this(false);
  }
  public ClusterServiceClassSpecBuilder(Boolean validationEnabled) {
    this(new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,ClusterServiceClassSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,ClusterServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withBindable(instance.getBindable());
      fluent.withBindingRetrievable(instance.getBindingRetrievable());
      fluent.withClusterServiceBrokerName(instance.getClusterServiceBrokerName());
      fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters());
      fluent.withDescription(instance.getDescription());
      fluent.withExternalID(instance.getExternalID());
      fluent.withExternalMetadata(instance.getExternalMetadata());
      fluent.withExternalName(instance.getExternalName());
      fluent.withPlanUpdatable(instance.getPlanUpdatable());
      fluent.withRequires(instance.getRequires());
      fluent.withTags(instance.getTags());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpec instance) {
    this(instance,false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withBindable(instance.getBindable());
      this.withBindingRetrievable(instance.getBindingRetrievable());
      this.withClusterServiceBrokerName(instance.getClusterServiceBrokerName());
      this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters());
      this.withDescription(instance.getDescription());
      this.withExternalID(instance.getExternalID());
      this.withExternalMetadata(instance.getExternalMetadata());
      this.withExternalName(instance.getExternalName());
      this.withPlanUpdatable(instance.getPlanUpdatable());
      this.withRequires(instance.getRequires());
      this.withTags(instance.getTags());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterServiceClassSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterServiceClassSpec build() {
    ClusterServiceClassSpec buildable = new ClusterServiceClassSpec(fluent.getBindable(),fluent.getBindingRetrievable(),fluent.getClusterServiceBrokerName(),fluent.getDefaultProvisionParameters(),fluent.getDescription(),fluent.getExternalID(),fluent.getExternalMetadata(),fluent.getExternalName(),fluent.getPlanUpdatable(),fluent.getRequires(),fluent.getTags());
    return buildable;
  }
  
}

==> servicecatalog-model-6.8.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceClassSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterServiceClassSpecBuilder extends ClusterServiceClassSpecFluent<ClusterServiceClassSpecBuilder> implements VisitableBuilder<ClusterServiceClassSpec,ClusterServiceClassSpecBuilder>{
  public ClusterServiceClassSpecBuilder() {
    this(false);
  }
  public ClusterServiceClassSpecBuilder(Boolean validationEnabled) {
    this(new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,ClusterServiceClassSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,ClusterServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterServiceClassSpec());

    if (instance != null) {
      fluent.withBindable(instance.getBindable());
      fluent.withBindingRetrievable(instance.getBindingRetrievable());
      fluent.withClusterServiceBrokerName(instance.getClusterServiceBrokerName());
      fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters());
      fluent.withDescription(instance.getDescription());
      fluent.withExternalID(instance.getExternalID());
      fluent.withExternalMetadata(instance.getExternalMetadata());
      fluent.withExternalName(instance.getExternalName());
      fluent.withPlanUpdatable(instance.getPlanUpdatable());
      fluent.withRequires(instance.getRequires());
      fluent.withTags(instance.getTags());
      fluent.withBindable(instance.getBindable());
      fluent.withBindingRetrievable(instance.getBindingRetrievable());
      fluent.withClusterServiceBrokerName(instance.getClusterServiceBrokerName());
      fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters());
      fluent.withDescription(instance.getDescription());
      fluent.withExternalID(instance.getExternalID());
      fluent.withExternalMetadata(instance.getExternalMetadata());
      fluent.withExternalName(instance.getExternalName());
      fluent.withPlanUpdatable(instance.getPlanUpdatable());
      fluent.withRequires(instance.getRequires());
      fluent.withTags(instance.getTags());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpec instance) {
    this(instance,false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterServiceClassSpec());

    if (instance != null) {
      this.withBindable(instance.getBindable());
      this.withBindingRetrievable(instance.getBindingRetrievable());
      this.withClusterServiceBrokerName(instance.getClusterServiceBrokerName());
      this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters());
      this.withDescription(instance.getDescription());
      this.withExternalID(instance.getExternalID());
      this.withExternalMetadata(instance.getExternalMetadata());
      this.withExternalName(instance.getExternalName());
      this.withPlanUpdatable(instance.getPlanUpdatable());
      this.withRequires(instance.getRequires());
      this.withTags(instance.getTags());
      this.withBindable(instance.getBindable());
      this.withBindingRetrievable(instance.getBindingRetrievable());
      this.withClusterServiceBrokerName(instance.getClusterServiceBrokerName());
      this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters());
      this.withDescription(instance.getDescription());
      this.withExternalID(instance.getExternalID());
      this.withExternalMetadata(instance.getExternalMetadata());
      this.withExternalName(instance.getExternalName());
      this.withPlanUpdatable(instance.getPlanUpdatable());
      this.withRequires(instance.getRequires());
      this.withTags(instance.getTags());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterServiceClassSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterServiceClassSpec build() {
    ClusterServiceClassSpec buildable = new ClusterServiceClassSpec(fluent.getBindable(),fluent.getBindingRetrievable(),fluent.getClusterServiceBrokerName(),fluent.getDefaultProvisionParameters(),fluent.getDescription(),fluent.getExternalID(),fluent.getExternalMetadata(),fluent.getExternalName(),fluent.getPlanUpdatable(),fluent.getRequires(),fluent.getTags());
    return buildable;
  }
  
}
